@@ -5,7 +5,9 @@ from mw_python_sdk import create_dataset, delete_dataset, upload_file
 class TestCreateDataset(unittest.TestCase):
     def test_dataset_create(self):
         try:
-            dataset = create_dataset("llama3chinese")
+            dataset = create_dataset(
+                "llama3chinese", "downloads", "", "llama3 are cool"
+            )
             print(dataset.title)
             assert dataset.title == "llama3chinese"
             upload_file("README.md", "test/README.md", dataset)
