@@ -6,7 +6,7 @@ class TestDownloadFile(unittest.TestCase):
     def test_download(self):
         dataset_id_tmp = "66b08ec9898e74a8232bb2d1"
         try:
-            download_dir(dataset_id_tmp)
+            download_dir("638456025305bf4b57c4a244", local_dir="downloads")
         except Exception as err:
             print(f"An error occurred: {err}")
 
